******************************
The sherpa.astro.io.wcs module
******************************

.. currentmodule:: sherpa.astro.io.wcs

.. automodule:: sherpa.astro.io.wcs

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      WCS

Class Inheritance Diagram
=========================

.. inheritance-diagram:: WCS
   :parts: 1
